diff --git a/db_qbe.php b/db_qbe.php
index 0f5d9054f1..f27bd1f1b8 100644
--- a/db_qbe.php
+++ b/db_qbe.php
@@ -11,6 +11,36 @@
*/
require_once 'libraries/common.inc.php';
+/**
+ * Sets globals from $_POST
+ */
+$post_params = array(
+ 'Field',
+ 'Show',
+ 'Sort'
+);
+foreach ($post_params as $one_post_param) {
+ if (isset($_POST[$one_post_param])) {
+ $GLOBALS[$one_post_param] = $_POST[$one_post_param];
+ }
+}
+
+/**
+ * Sets globals from $_POST patterns, for Or* variables
+ * (additional criteria lines)
+ */
+
+$post_patterns = array(
+ '/^Or/i'
+);
+foreach (array_keys($_POST) as $post_key) {
+ foreach ($post_patterns as $one_post_pattern) {
+ if (preg_match($one_post_pattern, $post_key)) {
+ $GLOBALS[$post_key] = $_POST[$post_key];
+ }
+ }
+}
+
/**
* Gets the relation settings
*/
diff --git a/db_search.php b/db_search.php
index 458a45b881..07de04675d 100644
--- a/db_search.php
+++ b/db_search.php
@@ -59,25 +59,16 @@ if (empty($_REQUEST['criteriaSearchType'])
unset($_REQUEST['submit_search']);
} else {
$criteriaSearchType = (int) $_REQUEST['criteriaSearchType'];
- $option_str = $searchTypes[$_REQUEST['criteriaSearchType']];
+ $searchTypeDescription = $searchTypes[$_REQUEST['criteriaSearchType']];
}
if (empty($_REQUEST['criteriaSearchString'])
|| ! is_string($_REQUEST['criteriaSearchString'])
) {
+ $criteriaSearchString = '';
unset($_REQUEST['submit_search']);
- $searched = '';
} else {
- $searched = htmlspecialchars($_REQUEST['criteriaSearchString']);
- // For "as regular expression" (search option 4), we should not treat
- // this as an expression that contains a LIKE (second parameter of
- // sqlAddSlashes()).
- //
- // Usage example: If user is seaching for a literal $ in a regexp search,
- // he should enter \$ as the value.
- $criteriaSearchString = $common_functions->sqlAddSlashes(
- $_REQUEST['criteriaSearchString'], ($criteriaSearchType == 4 ? false : true)
- );
+ $criteriaSearchString = $_REQUEST['criteriaSearchString'];
}
$criteriaTables = array();
@@ -121,8 +112,8 @@ if ( $GLOBALS['is_ajax_request'] != true) {
if (isset($_REQUEST['submit_search'])) {
$response->addHTML(
PMA_dbSearchGetSearchResults(
- $criteriaTables, $searched, $option_str,
- $criteriaSearchString, $criteriaSearchType,
+ $criteriaTables, $searchTypeDescription,
+ $criteriaSearchString, $criteriaSearchType,
(! empty($criteriaColumnName) ? $criteriaColumnName : '')
)
);
@@ -140,8 +131,9 @@ if ($GLOBALS['is_ajax_request'] == true) {
// Add search form
$response->addHTML(
PMA_dbSearchGetSelectionForm(
- $searched, $criteriaSearchType, $tables_names_only, $criteriaTables,
- $url_params, (! empty($criteriaColumnName) ? $criteriaColumnName : '')
+ $criteriaSearchString, $criteriaSearchType, $tables_names_only,
+ $criteriaTables, $url_params,
+ (! empty($criteriaColumnName) ? $criteriaColumnName : '')
)
);
?>
diff --git a/libraries/CommonFunctions.class.php b/libraries/CommonFunctions.class.php
index 50b520162c..439a49710e 100644
--- a/libraries/CommonFunctions.class.php
+++ b/libraries/CommonFunctions.class.php
@@ -3515,7 +3515,7 @@ class PMA_CommonFunctions
* Prepare the form used to select a file to import from the server upload
* directory
*
- * @param array $import_list array of import types
+ * @param array $import_list array of import plugins
* @param string $uploaddir upload directory
*
* @return void
@@ -3533,11 +3533,12 @@ class PMA_CommonFunctions
. '';
$extensions = '';
- foreach ($import_list as $val) {
+ foreach ($import_list as $import_plugin) {
if (! empty($extensions)) {
$extensions .= '|';
}
- $extensions .= $val['extension'];
+ $properties = $import_plugin->getProperties();
+ $extensions .= $properties['extension'];
}
$matcher = '@\.(' . $extensions . ')(\.('
diff --git a/libraries/plugins/export/ExportJson.class.php b/libraries/plugins/export/ExportJson.class.php
index 9d13b85f5c..21d57f4c12 100644
--- a/libraries/plugins/export/ExportJson.class.php
+++ b/libraries/plugins/export/ExportJson.class.php
@@ -135,7 +135,7 @@ class ExportJson extends ExportPlugin
}
/**
- * Outputs the content of a table in CSV format
+ * Outputs the content of a table in JSON format
*
* @param string $db database name
* @param string $table table name
diff --git a/libraries/plugins/export/README b/libraries/plugins/export/README
new file mode 100644
index 0000000000..3d69bc1bd7
--- /dev/null
+++ b/libraries/plugins/export/README
@@ -0,0 +1,252 @@
+This directory holds export plugins for phpMyAdmin. Any new plugin should
+basically follow the structure presented here. Official plugins need to
+have str* messages with their definition in language files, but if you build
+some plugins for your use, you can directly use texts in plugin.
+
+setProperties();
+ }
+
+ // optional - declare global variables and use getters later
+ /**
+ * Initialize the local variables that are used specific for export SQL
+ *
+ * @global type $global_variable_name
+ * [..]
+ *
+ * @return void
+ */
+ protected function initSpecificVariables()
+ {
+ global $global_variable_name;
+ $this->_setGlobalVariableName($global_variable_name);
+ }
+
+ /**
+ * Sets the export plugin properties.
+ * Called in the constructor.
+ *
+ * @return void
+ */
+ protected function setProperties()
+ {
+ // optional - get globals
+
+ // set properties
+ $this->properties = array( // set name of your plugin
+ 'text' => __('[Name]'), // text to be displayed as choice
+ 'extension' => '[ext]', // extension this plugin can handle
+ 'options' => array(), // array of options
+ 'options_text' => __('Options')
+ );
+
+ // optional :
+ // type - bool or text, or begin/end group_subgroup
+ // name - form element name
+ // text - description in GUI
+ // size - size of text element (optional)
+ // len - maximal size of input (optional)
+ $this->properties['options'] = array(
+ array(
+ 'type' => 'begin_group',
+ 'name' => 'general_opts'
+ ),
+ [..],
+ array(
+ 'type' => 'end_group'
+ )
+ );
+ }
+
+ /**
+ * This method is called when any PluginManager to which the observer
+ * is attached calls PluginManager::notify()
+ *
+ * @param SplSubject $subject The PluginManager notifying the observer
+ * of an update.
+ *
+ * @return void
+ */
+ public function update (SplSubject $subject)
+ {
+ }
+
+ /**
+ * Outputs export header
+ *
+ * @return bool Whether it succeeded
+ */
+ public function exportHeader ()
+ {
+ // implementation
+ return true;
+ }
+
+ /**
+ * Outputs export footer
+ *
+ * @return bool Whether it succeeded
+ */
+ public function exportFooter ()
+ {
+ // implementation
+ return true;
+ }
+
+ /**
+ * Outputs database header
+ *
+ * @param string $db Database name
+ *
+ * @return bool Whether it succeeded
+ */
+ public function exportDBHeader ($db)
+ {
+ // implementation
+ return true;
+ }
+
+ /**
+ * Outputs database footer
+ *
+ * @param string $db Database name
+ *
+ * @return bool Whether it succeeded
+ */
+ public function exportDBFooter ($db)
+ {
+ // implementation
+ return true;
+ }
+
+ /**
+ * Outputs CREATE DATABASE statement
+ *
+ * @param string $db Database name
+ *
+ * @return bool Whether it succeeded
+ */
+ public function exportDBCreate($db)
+ {
+ // implementation
+ return true;
+ }
+
+ /**
+ * Outputs the content of a table in [Name] format
+ *
+ * @param string $db database name
+ * @param string $table table name
+ * @param string $crlf the end of line sequence
+ * @param string $error_url the url to go back in case of error
+ * @param string $sql_query SQL query for obtaining data
+ *
+ * @return bool Whether it succeeded
+ */
+ public function exportData($db, $table, $crlf, $error_url, $sql_query)
+ {
+ // implementation;
+ return true;
+ }
+
+ // optional - implement other methods defined in ExportPlugin.class.php:
+ // - exportRoutines()
+ // - exportStructure()
+ // - getTableDefStandIn()
+ // - getTriggers()
+
+ // optional - implement other private methods in order to avoid
+ // having huge methods or avoid duplicate code. Make use of them
+ // as well as of the getters and setters declared both here
+ // and in the ExportPlugin class
+
+
+ // optional:
+ /* ~~~~~~~~~~~~~~~~~~~~ Getters and Setters ~~~~~~~~~~~~~~~~~~~~ */
+
+
+ /**
+ * Getter description
+ *
+ * @return type
+ */
+ private function _getMyOptionalVariable()
+ {
+ return $this->_myOptionalVariable;
+ }
+
+ /**
+ * Setter description
+ *
+ * @param type $my_optional_variable description
+ *
+ * @return void
+ */
+ private function _setMyOptionalVariable($my_optional_variable)
+ {
+ $this->_myOptionalVariable = $my_optional_variable;
+ }
+
+ /**
+ * Getter description
+ *
+ * @return type
+ */
+ private function _getGlobalVariableName()
+ {
+ return $this->_globalVariableName;
+ }
+
+ /**
+ * Setter description
+ *
+ * @param type $global_variable_name description
+ *
+ * @return void
+ */
+ private function _setGlobalVariableName($global_variable_name)
+ {
+ $this->_globalVariableName = $global_variable_name;
+ }
+}
+?>
\ No newline at end of file
diff --git a/libraries/plugins/import/README b/libraries/plugins/import/README
index 7bf8e39ab7..8e840658a1 100644
--- a/libraries/plugins/import/README
+++ b/libraries/plugins/import/README
@@ -1,43 +1,149 @@
-Todo: Rewrite!
-
-This directory holds import plugins for phpMyAdmin. Plugin should
-basically look like following code. Official plugins need to have str*
-messages with their definition in language files, if you build some
-plugins for your use, you can use directly texts in plugin.
+This directory holds import plugins for phpMyAdmin. Any new plugin should
+basically follow the structure presented here. Official plugins need to
+have str* messages with their definition in language files, but if you build
+some plugins for your use, you can directly use texts in plugin.
'strName', // text to be displayed as choice
- 'extension' => '', // extension this plugin can handle
- 'options' => array( // array of options for your plugin (optional)
- array('type' => '', 'name' => '', 'text' => ''), // type: bool or text, name: form element name, text: description in GUI, size: size of text element (optional). len: maximal size of input (optional)
- ),
- 'options_text' => 'strNameImportOptions', // text to describe plugin options (must be set if options are used)
- );
-} else {
-/* We do not define function when plugin is just queried for information above */
- $buffer = '';
- while (!($finished && $i >= $len) && !$error && !$timeout_passed) {
- $data = PMA_importGetNextChunk();
- if ($data === false) {
- // subtract data we didn't handle yet and stop processing
- $offset -= strlen($buffer);
- break;
- } elseif ($data === true) {
- // Handle rest of buffer
- } else {
- // Append new data to buffer
- $buffer .= $data;
- }
- // PARSE $buffer here, post sql queries using:
- PMA_importRunQuery($sql, $verbose_sql_with_comments);
- } // End of import loop
- // Commit any possible data in buffers
- PMA_importRunQuery();
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ * [Name] import plugin for phpMyAdmin
+ *
+ * @package PhpMyAdmin-Import
+ * @subpackage [Name]
+ */
+if (! defined('PHPMYADMIN')) {
+ exit;
}
-?>
+
+/* Get the import interface */
+require_once "libraries/plugins/ImportPlugin.class.php";
+
+/**
+ * Handles the import for the [Name] format
+ *
+ * @package PhpMyAdmin-Import
+ */
+class Import[Name] extends ImportPlugin
+{
+ /**
+ * optional - declare variables and descriptions
+ *
+ * @var type
+ */
+ private $_myOptionalVariable;
+
+ /**
+ * Constructor
+ */
+ public function __construct()
+ {
+ $this->setProperties();
+ }
+
+ /**
+ * Sets the import plugin properties.
+ * Called in the constructor.
+ *
+ * @return void
+ */
+ protected function setProperties()
+ {
+ // optional - get globals
+
+ // set properties
+ $this->properties = array( // set name of your plugin
+ 'text' => __('[Name]'), // text to be displayed as choice
+ 'extension' => '[ext]', // extension this plugin can handle
+ 'options' => array(), // array of options
+ 'options_text' => __('Options')
+ );
+
+ // optional :
+ // type - bool or text, or begin/end group_subgroup
+ // name - form element name
+ // text - description in GUI
+ // size - size of text element (optional)
+ // len - maximal size of input (optional)
+ $this->properties['options'] = array(
+ array(
+ 'type' => 'begin_group',
+ 'name' => 'general_opts'
+ ),
+ [..],
+ array(
+ 'type' => 'end_group'
+ )
+ );
+ }
+
+ /**
+ * This method is called when any PluginManager to which the observer
+ * is attached calls PluginManager::notify()
+ *
+ * @param SplSubject $subject The PluginManager notifying the observer
+ * of an update.
+ *
+ * @return void
+ */
+ public function update (SplSubject $subject)
+ {
+ }
+
+ /**
+ * Handles the whole import logic
+ *
+ * @return void
+ */
+ public function doImport()
+ {
+ // get globals (others are optional)
+ global $error, $timeout_passed, $finished;
+
+ $buffer = '';
+ while (! ($finished && $i >= $len) && ! $error && ! $timeout_passed) {
+ $data = PMA_importGetNextChunk();
+ if ($data === false) {
+ // subtract data we didn't handle yet and stop processing
+ $offset -= strlen($buffer);
+ break;
+ } elseif ($data === true) {
+ // Handle rest of buffer
+ } else {
+ // Append new data to buffer
+ $buffer .= $data;
+ }
+ // PARSE $buffer here, post sql queries using:
+ PMA_importRunQuery($sql, $verbose_sql_with_comments);
+ } // End of import loop
+ // Commit any possible data in buffers
+ PMA_importRunQuery();
+ }
+
+
+ // optional:
+ /* ~~~~~~~~~~~~~~~~~~~~ Getters and Setters ~~~~~~~~~~~~~~~~~~~~ */
+
+
+ /**
+ * Getter description
+ *
+ * @return type
+ */
+ private function _getMyOptionalVariable()
+ {
+ return $this->_myOptionalVariable;
+ }
+
+ /**
+ * Setter description
+ *
+ * @param type $my_optional_variable description
+ *
+ * @return void
+ */
+ private function _setMyOptionalVariable($my_optional_variable)
+ {
+ $this->_myOptionalVariable = $my_optional_variable;
+ }
+}
+?>
\ No newline at end of file
diff --git a/po/da.po b/po/da.po
index 5906659ad7..8dd9b15df6 100644
--- a/po/da.po
+++ b/po/da.po
@@ -4,7 +4,7 @@ msgstr ""
"Project-Id-Version: phpMyAdmin 4.0.0-dev\n"
"Report-Msgid-Bugs-To: phpmyadmin-devel@lists.sourceforge.net\n"
"POT-Creation-Date: 2012-07-03 09:19+0200\n"
-"PO-Revision-Date: 2012-06-25 16:57+0200\n"
+"PO-Revision-Date: 2012-07-04 01:34+0200\n"
"Last-Translator: Aputsiaq Niels Janussen
\n"
"Language-Team: danish \n"
"Language: da\n"
@@ -12,7 +12,7 @@ msgstr ""
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
"Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Weblate 1.0\n"
+"X-Generator: Weblate 1.1\n"
#: browse_foreigners.php:36 browse_foreigners.php:60 js/messages.php:354
#: libraries/DisplayResults.class.php:609 server_privileges.php:1851
@@ -1868,15 +1868,14 @@ msgstr "Når der holdes over et punkt vises dets etiket."
#: js/messages.php:304
msgid "To zoom in, select a section of the plot with the mouse."
-msgstr ""
+msgstr "For at forstørre, vælg en sektion af plottet med musen."
#: js/messages.php:306
-#, fuzzy
#| msgid "Click reset zoom link to come back to original state."
msgid "Click reset zoom button to come back to original state."
msgstr ""
-"Klik på linket for nulstil zoom for at vende tilbage til den oprindelige "
-"tilstand."
+"Klik på knap til nulstilling af zoom for at vende tilbage til den "
+"oprindelige tilstand."
#: js/messages.php:308
msgid "Click a data point to view and possibly edit the data row."
@@ -1900,10 +1899,9 @@ msgid "Query results"
msgstr "Forespørgselsresultater"
#: js/messages.php:315
-#, fuzzy
#| msgid "Data pointer size"
msgid "Data point content"
-msgstr "Data pointer-størrelse"
+msgstr "Datapunkt-indhold"
#: js/messages.php:318 tbl_change.php:244 tbl_indexes.php:249
#: tbl_indexes.php:284
@@ -2329,22 +2327,24 @@ msgstr "Mislykkedes med at formatere streng for reglen '%s'."
msgid ""
"Invalid rule declaration on line %1$s, expected line %2$s of previous rule"
msgstr ""
+"Ugyldig regel-deklaration på linje %1$s, forventede linje %2$s fra forrige "
+"regel"
#: libraries/Advisor.class.php:378
-#, fuzzy, php-format
+#, php-format
#| msgid "Invalid format of CSV input on line %d."
msgid "Invalid rule declaration on line %s"
-msgstr "Ugyldigt format for CSV-input på linie %d."
+msgstr "Ugyldig regel-deklaration på linie %s"
#: libraries/Advisor.class.php:386
#, php-format
msgid "Unexpected characters on line %s"
-msgstr ""
+msgstr "Uventet tegn på linje %s"
#: libraries/Advisor.class.php:400
#, php-format
msgid "Unexpected character on line %1$s. Expected tab, but found \"%2$s\""
-msgstr ""
+msgstr "Uventet tegn på linje %1$s. Forventede tabulering, men fandt \"%2$s\""
#: libraries/Advisor.class.php:425 server_status.php:972
msgid "per second"
@@ -2361,7 +2361,7 @@ msgstr "pr. time"
#: libraries/Advisor.class.php:434
msgid "per day"
-msgstr ""
+msgstr "per dag"
#: libraries/CommonFunctions.class.php:251
#, php-format
@@ -2654,10 +2654,10 @@ msgid "vertical"
msgstr "lodret"
#: libraries/DisplayResults.class.php:734
-#, fuzzy, php-format
+#, php-format
#| msgid "Headers every %s rows"
msgid "Headers every %s rows"
-msgstr "Overskrifter for hver %s rows"
+msgstr "Overskrifter for hver %s. række"
#: libraries/DisplayResults.class.php:1217
msgid "Sort by key"
@@ -2724,10 +2724,9 @@ msgid "Show binary contents as HEX"
msgstr "Vis binært indhold som HEX"
#: libraries/DisplayResults.class.php:1417
-#, fuzzy
#| msgid "Browser transformation"
msgid "Hide browser transformation"
-msgstr "Browser transformation"
+msgstr "Skjul browser-transformation"
#: libraries/DisplayResults.class.php:1426
msgid "Well Known Text"
@@ -2810,7 +2809,7 @@ msgstr "Link ikke fundet"
#: libraries/Error_Handler.class.php:65
msgid "Too many error messages, some are not displayed."
-msgstr ""
+msgstr "For mange fejlmeddelelser, nogle vises ikke."
#: libraries/File.class.php:235
msgid "File was not an uploaded file."
@@ -2876,10 +2875,9 @@ msgstr "Herefter skal cookies være slået til."
#: libraries/Header.class.php:500
#: libraries/plugins/auth/AuthenticationCookie.class.php:152
-#, fuzzy
#| msgid "Cookies must be enabled past this point."
msgid "Javascript must be enabled past this point"
-msgstr "Herefter skal cookies være slået til."
+msgstr "Herefter skal JavaScript være slået til"
#: libraries/Index.class.php:433 tbl_relation.php:540
msgid "No index defined!"
@@ -2990,10 +2988,9 @@ msgid "Designer"
msgstr "Designer"
#: libraries/Menu.class.php:484
-#, fuzzy
#| msgid "User"
msgid "Users"
-msgstr "Bruger"
+msgstr "Brugere"
#: libraries/Menu.class.php:505 server_synchronize.php:1320
#: server_synchronize.php:1327
@@ -3085,10 +3082,10 @@ msgid "unknown table status: "
msgstr "ukendt tabelstatus: "
#: libraries/Table.class.php:766
-#, fuzzy, php-format
+#, php-format
#| msgid "Source database"
msgid "Source database `%s` was not found!"
-msgstr "Kildedatabase"
+msgstr "Kildedatabasen '%s' blev ikke fundet!"
#: libraries/Table.class.php:774
#, fuzzy, php-format
diff --git a/po/fa.po b/po/fa.po
index e4ab1343d0..2c4478c63d 100644
--- a/po/fa.po
+++ b/po/fa.po
@@ -1,10 +1,10 @@
#
msgid ""
msgstr ""
-"Project-Id-Version: phpMyAdmin 4.0.0-dev\n"
+"Project-Id-Version: phpMyAdmin 3.5.2-dev\n"
"Report-Msgid-Bugs-To: phpmyadmin-devel@lists.sourceforge.net\n"
"POT-Creation-Date: 2012-07-03 09:19+0200\n"
-"PO-Revision-Date: 2012-07-03 16:34+0200\n"
+"PO-Revision-Date: 2012-07-04 11:24+0200\n"
"Last-Translator: Ashiyane Digital Security Team \n"
"Language-Team: persian \n"
"Language: fa\n"
@@ -426,10 +426,8 @@ msgstr "آخرین بازدید"
#, php-format
msgid "%s table"
msgid_plural "%s tables"
-msgstr[0] ""
-"%s جدول"
-msgstr[1] ""
-"%s جدولها"
+msgstr[0] "%s جدول"
+msgstr[1] "%s جدولها"
#: db_qbe.php:42
msgid "You have to choose at least one column to display"
@@ -891,8 +889,8 @@ msgid ""
"Chose \"GeomFromText\" from the \"Function\" column and paste the below "
"string into the \"Value\" field"
msgstr ""
-"گزینه \"GeomFromText\" را از ستون \"Function\" انتخاب کنید و رشته زیر را در "
-"فیلد \"مقدار(value)\" وارد کنید"
+"گزینه \"GeomFromText\" را از ستون \"Function\" انتخاب کنید و رشته زیر را در فیلد "
+"\"مقدار(value)\" وارد کنید"
#: import.php:88
#, php-format
@@ -1590,7 +1588,7 @@ msgstr "بارگیری لاگ ها"
#: js/messages.php:204
msgid "Monitor refresh failed"
-msgstr "رفرش مانیتور موفقیت آمیز نبود"
+msgstr "مانیتور رفرش ریت"
#: js/messages.php:205
msgid ""
@@ -1794,7 +1792,7 @@ msgstr "پاک کردن"
#: js/messages.php:269
msgid "The definition of a stored function must contain a RETURN statement!"
-msgstr "تعریف یک تابع ذخیره شده باید شامل یک دستور بازگشت باشد"
+msgstr "تعریف یک تابع ذخیره شده باید شامل یک دستور بازگشت باشد!"
#: js/messages.php:272 libraries/rte/rte_routines.lib.php:747
msgid "ENUM/SET editor"
@@ -1816,14 +1814,14 @@ msgstr "هر کدام از مقادیر را در یک فیلد وارد کنی
#: js/messages.php:276
#, php-format
msgid "Add %d value(s)"
-msgstr "اضافه کردن مقدار %d "
+msgstr "اضافه کردن مقدار %d"
#: js/messages.php:279
msgid ""
"Note: If the file contains multiple tables, they will be combined into one"
msgstr ""
"توجه داشته باشید:اگر این فایل شامل جداول چند گانه میباشد,انها به یکی تبدیل "
-"خواهند شد "
+"خواهند شد"
#: js/messages.php:282
msgid "Hide query box"
@@ -1876,7 +1874,7 @@ msgstr "زوم جستجو"
#: js/messages.php:300
msgid "Each point represents a data row."
-msgstr ".هر نقطه نشان دهنده یک سطر داده ها"
+msgstr "هر نقطه نشان دهنده یک سطر داده ها."
#: js/messages.php:302
msgid "Hovering over a point will show its label."
@@ -1893,31 +1891,31 @@ msgstr ""
#: js/messages.php:308
msgid "Click a data point to view and possibly edit the data row."
msgstr ""
+"با کیک بر روی داده ها ان ها را بینید و احتمالا ردیف داده ها راویرایش کنید."
#: js/messages.php:310
msgid "The plot can be resized by dragging it along the bottom right corner."
msgstr ""
+"تغییر اندازه طرح با کشیدن آن در امتداد گوشه پایین سمت راس میتواند انجام "
+"گیرد."
#: js/messages.php:312
-#, fuzzy
#| msgid "Add/Delete columns"
msgid "Select two columns"
-msgstr "اضافه/حذف ستون ها"
+msgstr "انتخاب دو ستون"
#: js/messages.php:313
msgid "Select two different columns"
-msgstr ""
+msgstr "انتخاب دو ستون متفاوت"
#: js/messages.php:314
-#, fuzzy
#| msgid "SQL result"
msgid "Query results"
-msgstr "نتيجه SQL"
+msgstr "نتایج پرس و جو"
#: js/messages.php:315
-#, fuzzy
msgid "Data point content"
-msgstr "توضيحات جدول"
+msgstr "محتوای داده ها"
#: js/messages.php:318 tbl_change.php:244 tbl_indexes.php:249
#: tbl_indexes.php:284
@@ -1926,27 +1924,25 @@ msgstr "در نظر نگرفتن"
#: js/messages.php:319 libraries/DisplayResults.class.php:2592
msgid "Copy"
-msgstr ""
+msgstr "کپی"
#: js/messages.php:334
-#, fuzzy
msgid "Add columns"
-msgstr "افزودن ستون جديد"
+msgstr "افزودن ستونها"
#: js/messages.php:337
msgid "Select referenced key"
-msgstr ""
+msgstr "انتخاب کلید اشاره"
#: js/messages.php:338
msgid "Select Foreign Key"
-msgstr ""
+msgstr "انتخاب کلید خارجی"
#: js/messages.php:339
msgid "Please select the primary key or a unique key"
-msgstr ""
+msgstr "لطفا کلید اولیه و یا یک کلید منحصر به فرد را انتخاب کنید"
#: js/messages.php:340 pmd_general.php:97 tbl_relation.php:559
-#, fuzzy
#| msgid "Choose field to display"
msgid "Choose column to display"
msgstr "ستون را براي نمايش انتخاب نماييد"
@@ -1956,34 +1952,37 @@ msgid ""
"You haven't saved the changes in the layout. They will be lost if you don't "
"save them. Do you want to continue?"
msgstr ""
+"تغییر در طرح شما ذخیره نشده است. آنها از دست خواهد رفت اگر شما آنها را ذخیره "
+"نکنید. ایا شما میخواهید ادامه دهید؟"
#: js/messages.php:344
msgid "Add an option for column "
-msgstr ""
+msgstr "اضافه کردن تنظیمات برای ستون "
#: js/messages.php:347
msgid "Press escape to cancel editing"
-msgstr ""
+msgstr "دکمه ی escape را برای صرفنظر کردن از ویرایش"
#: js/messages.php:348
msgid ""
"You have edited some data and they have not been saved. Are you sure you "
"want to leave this page before saving the data?"
msgstr ""
+"شما مقداری داده ویرایش کردید و ان ها ذخیره نشده اند.ایا شما برای ترک این "
+"صفحه بدون ذخیره کردن داده ها اطمینان دارید؟"
#: js/messages.php:349
msgid "Drag to reorder"
-msgstr ""
+msgstr "برای دوباره مرتب کردن drag کنید"
#: js/messages.php:350
-#, fuzzy
#| msgid "Click to select"
msgid "Click to sort"
-msgstr "برای انتخاب کلیک کنبد"
+msgstr "برای مرتب کردن کلیک کنید"
#: js/messages.php:351
msgid "Click to mark/unmark"
-msgstr ""
+msgstr "برای علامتگذاری / برداشتن علامت اینجا را کلبک کن"
#: js/messages.php:352
msgid "Double-click to copy column name"
@@ -1991,22 +1990,25 @@ msgstr ""
#: js/messages.php:353
msgid "Click the drop-down arrow to toggle column's visibility"
-msgstr ""
+msgstr "با کلیک بر روی منوی کشویی به ضامن دید ستون"
#: js/messages.php:355
msgid ""
"This table does not contain a unique column. Features related to the grid "
"edit, checkbox, Edit, Copy and Delete links may not work after saving."
msgstr ""
+"این جدول هیچ مقدار کلیدی ندارد. امکانات ویرایش جدولی، چک باکس ها ، ویرایش ، "
+"کپی و حذف ممکن است کار نکنند."
#: js/messages.php:356
msgid ""
"You can also edit most columns by clicking directly on their content."
msgstr ""
+"شما همچنین می توانید بیشتر ستون ها را با کلیک روی آنها ویرایش کنید."
#: js/messages.php:357
msgid "Go to link"
-msgstr ""
+msgstr "به لینک بروید"
#: js/messages.php:358
#, fuzzy
@@ -2025,27 +2027,23 @@ msgid "Show data row(s)"
msgstr "شنبه"
#: js/messages.php:363
-#, fuzzy
#| msgid "Change password"
msgid "Generate password"
msgstr "تغيير اسم رمز"
#: js/messages.php:364 libraries/replication_gui.lib.php:381
-#, fuzzy
msgid "Generate"
-msgstr "توليدشده توسط"
+msgstr "توليد کن"
#: js/messages.php:365
-#, fuzzy
#| msgid "Change password"
msgid "Change Password"
msgstr "تغيير اسم رمز"
#: js/messages.php:368 tbl_structure.php:470
-#, fuzzy
#| msgid "Mon"
msgid "More"
-msgstr "دوشنبه"
+msgstr "بیشتر"
#: js/messages.php:371 setup/lib/index.lib.php:188
#, php-format
@@ -2053,28 +2051,26 @@ msgid ""
"A newer version of phpMyAdmin is available and you should consider "
"upgrading. The newest version is %s, released on %s."
msgstr ""
+"نسخه جدید phpmyadmin آمده است و شما باید به فکر به روز رسانی باشید. جدیدترین "
+"نسخه %s و در %s بیرون آمده است."
#. l10n: Latest available phpMyAdmin version
#: js/messages.php:373
-#, fuzzy
#| msgid "Last version"
msgid ", latest stable version:"
-msgstr "نسخه قبلی"
+msgstr "نسخه قبلی:"
#: js/messages.php:374
-#, fuzzy
msgid "up to date"
-msgstr "No databases"
+msgstr "به روز"
#. l10n: Display text for calendar close link
#: js/messages.php:393
-#, fuzzy
#| msgid "None"
msgid "Done"
-msgstr "خير"
+msgstr "انجام شد"
#: js/messages.php:397
-#, fuzzy
#| msgid "Previous"
msgctxt "Previous month"
msgid "Prev"
@@ -2089,29 +2085,25 @@ msgstr "بعد"
#. l10n: Display text for current month link in calendar
#: js/messages.php:405
-#, fuzzy
#| msgid "Total"
msgid "Today"
-msgstr "جمع كل"
+msgstr "امروز"
#: js/messages.php:409
-#, fuzzy
#| msgid "Binary"
msgid "January"
-msgstr "دودويي"
+msgstr "ژانویه"
#: js/messages.php:410
msgid "February"
-msgstr ""
+msgstr "فوریه"
#: js/messages.php:411
-#, fuzzy
#| msgid "Mar"
msgid "March"
msgstr "مارس"
#: js/messages.php:412
-#, fuzzy
#| msgid "Apr"
msgid "April"
msgstr "آوريل"
@@ -2121,40 +2113,36 @@ msgid "May"
msgstr "مي"
#: js/messages.php:414
-#, fuzzy
#| msgid "Jun"
msgid "June"
msgstr "ژوئن"
#: js/messages.php:415
-#, fuzzy
#| msgid "Jul"
msgid "July"
msgstr "جولاي"
#: js/messages.php:416
-#, fuzzy
#| msgid "Aug"
msgid "August"
msgstr "آگوست"
#: js/messages.php:417
msgid "September"
-msgstr ""
+msgstr "سپتامبر"
#: js/messages.php:418
-#, fuzzy
#| msgid "Oct"
msgid "October"
msgstr "اكتبر"
#: js/messages.php:419
msgid "November"
-msgstr ""
+msgstr "نوامبر"
#: js/messages.php:420
msgid "December"
-msgstr ""
+msgstr "دسامبر"
#. l10n: Short month name
#: js/messages.php:427 libraries/CommonFunctions.class.php:1721
@@ -2178,7 +2166,6 @@ msgstr "آوريل"
#. l10n: Short month name
#: js/messages.php:435 libraries/CommonFunctions.class.php:1729
-#, fuzzy
#| msgid "May"
msgctxt "Short month name"
msgid "May"
@@ -2220,19 +2207,16 @@ msgid "Dec"
msgstr "دسامبر"
#: js/messages.php:455
-#, fuzzy
#| msgid "Sun"
msgid "Sunday"
msgstr "يكشنبه"
#: js/messages.php:456
-#, fuzzy
#| msgid "Mon"
msgid "Monday"
msgstr "دوشنبه"
#: js/messages.php:457
-#, fuzzy
#| msgid "Tue"
msgid "Tuesday"
msgstr "سهشنبه"
@@ -2246,7 +2230,6 @@ msgid "Thursday"
msgstr "پنجشنبه"
#: js/messages.php:460
-#, fuzzy
#| msgid "Fri"
msgid "Friday"
msgstr "جمعه"
@@ -2257,7 +2240,6 @@ msgstr "شنبه"
#. l10n: Short week day name
#: js/messages.php:468
-#, fuzzy
#| msgctxt "Short week day name"
#| msgid "Sun"
msgid "Sun"
@@ -2295,49 +2277,42 @@ msgstr "شنبه"
#. l10n: Minimal week day name
#: js/messages.php:487
-#, fuzzy
#| msgid "Sun"
msgid "Su"
msgstr "يكشنبه"
#. l10n: Minimal week day name
#: js/messages.php:489
-#, fuzzy
#| msgid "Mon"
msgid "Mo"
msgstr "دوشنبه"
#. l10n: Minimal week day name
#: js/messages.php:491
-#, fuzzy
#| msgid "Tue"
msgid "Tu"
msgstr "سهشنبه"
#. l10n: Minimal week day name
#: js/messages.php:493
-#, fuzzy
#| msgid "Wed"
msgid "We"
msgstr "چهارشنبه"
#. l10n: Minimal week day name
#: js/messages.php:495
-#, fuzzy
#| msgid "Thu"
msgid "Th"
msgstr "پنجشنبه"
#. l10n: Minimal week day name
#: js/messages.php:497
-#, fuzzy
#| msgid "Fri"
msgid "Fr"
msgstr "جمعه"
#. l10n: Minimal week day name
#: js/messages.php:499
-#, fuzzy
#| msgid "Sat"
msgid "Sa"
msgstr "شنبه"
@@ -2350,15 +2325,14 @@ msgstr "هفته"
#. l10n: Month-year order for calendar, use either "calendar-month-year" or "calendar-year-month".
#: js/messages.php:506
msgid "calendar-month-year"
-msgstr ""
+msgstr "تقویم-ماه-سال"
#. l10n: Year suffix for calendar, "none" is empty.
#: js/messages.php:508
-#, fuzzy
#| msgid "None"
msgctxt "Year suffix"
msgid "none"
-msgstr "خير"
+msgstr "هیچ"
#: js/messages.php:517
msgid "Hour"
@@ -2433,7 +2407,7 @@ msgstr "در ساعت"
#: libraries/Advisor.class.php:434
msgid "per day"
-msgstr ""
+msgstr "هر روز"
#: libraries/CommonFunctions.class.php:251
#, php-format
@@ -2566,7 +2540,6 @@ msgstr "پارامتر یافت نشد:"
#: libraries/CommonFunctions.class.php:2624
#: libraries/CommonFunctions.class.php:2628
#: libraries/DisplayResults.class.php:578
-#, fuzzy
#| msgid "Begin"
msgctxt "First page"
msgid "Begin"
@@ -2586,16 +2559,14 @@ msgstr "قبل"
#: libraries/CommonFunctions.class.php:2664
#: libraries/DisplayResults.class.php:637 server_binlog.php:175
#: server_binlog.php:177
-#, fuzzy
#| msgid "Next"
msgctxt "Next page"
msgid "Next"
-msgstr "بعد"
+msgstr "بعدی"
#: libraries/CommonFunctions.class.php:2662
#: libraries/CommonFunctions.class.php:2665
#: libraries/DisplayResults.class.php:662
-#, fuzzy
#| msgid "End"
msgctxt "Last page"
msgid "End"
@@ -2629,7 +2600,6 @@ msgstr "برای انتخاب کلیک کنبد"
#: libraries/plugins/export/ExportLatex.class.php:483
#: libraries/tbl_properties.inc.php:756 pmd_general.php:167
#: server_privileges.php:724 server_replication.php:345 tbl_tracking.php:306
-#, fuzzy
#| msgid "structure"
msgid "Structure"
msgstr "ساختار"
@@ -2647,7 +2617,6 @@ msgstr "SQL"
#: libraries/CommonFunctions.class.php:3591
#: libraries/CommonFunctions.class.php:3592 libraries/Menu.class.php:294
#: libraries/sql_query_form.lib.php:307 libraries/sql_query_form.lib.php:310
-#, fuzzy
#| msgid "Insert"
msgid "Insert"
msgstr "درج"
@@ -2662,7 +2631,6 @@ msgstr "فهرست"
#: libraries/CommonFunctions.class.php:3391 libraries/Menu.class.php:313
#: libraries/Menu.class.php:336 libraries/Menu.class.php:400
#: view_operations.php:84
-#, fuzzy
msgid "Operations"
msgstr "عمليات"
@@ -2697,11 +2665,11 @@ msgstr "چاپ"
#: libraries/Config.class.php:915
#, php-format
msgid "Existing configuration file (%s) is not readable."
-msgstr ""
+msgstr "فایل تنظیمات فعلی (%s) قابل خواندن نیست."
#: libraries/Config.class.php:945
msgid "Wrong permissions on configuration file, should not be world writable!"
-msgstr ""
+msgstr "تنظمیات دسترسی اشتباه در فایل تنظیمات ، نباید قابل نوشتن جهانی باشد!"
#: libraries/Config.class.php:1521
msgid "Font size"
@@ -2907,11 +2875,11 @@ msgstr "پيوند پيدا نشد"
#: libraries/Error_Handler.class.php:65
msgid "Too many error messages, some are not displayed."
-msgstr ""
+msgstr "خطای زیاد،برخی نمایش داده نشدند."
#: libraries/File.class.php:235
msgid "File was not an uploaded file."
-msgstr ""
+msgstr "فایل آپلود شده نبود."
#: libraries/File.class.php:273
msgid "The uploaded file exceeds the upload_max_filesize directive in php.ini."
@@ -2999,7 +2967,6 @@ msgstr ""
#: libraries/Index.class.php:471 libraries/rte/rte_events.lib.php:488
#: libraries/rte/rte_routines.lib.php:1017 tbl_tracking.php:316
#: tbl_tracking.php:381
-#, fuzzy
msgid "Comment"
msgstr "توضيحات"
@@ -3143,9 +3110,8 @@ msgid "Could not save recent table"
msgstr ""
#: libraries/RecentTable.class.php:147
-#, fuzzy
msgid "Recent tables"
-msgstr "No tables"
+msgstr "جدول های اخیر"
#: libraries/RecentTable.class.php:154
msgid "There are no recent tables"
@@ -3214,8 +3180,8 @@ msgid ""
"Failed to cleanup table UI preferences (see $cfg['Servers'][$i]"
"['MaxTableUiprefs'] %s)"
msgstr ""
-"پاک سازی تنظیمات UI جداول موفقیت آمیز نبود(به $cfg['Servers'][$i]"
-"['MaxTableUiprefs'] %s مراجعه کنید)"
+"پاک سازی تنظیمات UI جداول موفقیت آمیز نبود(به "
+"$cfg['Servers'][$i]['MaxTableUiprefs'] %s مراجعه کنید)"
#: libraries/Table.class.php:1571
#, php-format
@@ -3224,8 +3190,8 @@ msgid ""
"after you refresh this page. Please check if the table structure has been "
"changed."
msgstr ""
-"مقدار UI \"%s\" را نمی توان ذخیره کرد.تغییرات انجام شد اما با رفرش صفحه از "
-"بین می روند.لطفا ساختار جدول خود را برای تغییرات چک کنید."
+"مقدار UI \"%s\" را نمی توان ذخیره کرد.تغییرات انجام شد اما با رفرش صفحه از بین "
+"می روند.لطفا ساختار جدول خود را برای تغییرات چک کنید."
#: libraries/TableSearch.class.php:211 libraries/insert_edit.lib.php:230
#: libraries/insert_edit.lib.php:236 libraries/rte/rte_routines.lib.php:1458
@@ -3718,8 +3684,7 @@ msgstr "ایندکس غلط در سرور : %s"
#: libraries/common.inc.php:632
#, php-format
msgid "Invalid hostname for server %1$s. Please review your configuration."
-msgstr ""
-"نام هاست برای سرور %1$s اشتباه است. لطفا تنظیمات خود را بازبینی نمایید."
+msgstr "نام هاست برای سرور %1$s اشتباه است. لطفا تنظیمات خود را بازبینی نمایید."
#: libraries/common.inc.php:849
msgid "Invalid authentication method set in configuration:"
@@ -3889,10 +3854,9 @@ msgid "SQL Validator is disabled"
msgstr ""
#: libraries/config/FormDisplay.class.php:811
-#, fuzzy
#| msgid "Link not found"
msgid "SOAP extension not found"
-msgstr "پيوند پيدا نشد"
+msgstr "کتابخانه SOAP یافت نشد"
#: libraries/config/FormDisplay.class.php:821
#, php-format
@@ -3932,9 +3896,8 @@ msgid "Improves efficiency of screen refresh"
msgstr ""
#: libraries/config/messages.inc.php:18
-#, fuzzy
msgid "Enable Ajax"
-msgstr "فعال"
+msgstr "ایجکس فعال شود"
#: libraries/config/messages.inc.php:19
msgid ""
@@ -4087,9 +4050,8 @@ msgid "Debug SQL"
msgstr ""
#: libraries/config/messages.inc.php:51
-#, fuzzy
msgid "Default display direction"
-msgstr "آمار پايگاههاي داده"
+msgstr "تنظیم پیش فرض جهت نمایش"
#: libraries/config/messages.inc.php:52
msgid "Tab that is displayed when entering a database"
@@ -4152,26 +4114,23 @@ msgid ""
msgstr ""
#: libraries/config/messages.inc.php:67
-#, fuzzy
#| msgid "Table maintenance"
msgid "Disable multi table maintenance"
-msgstr "نگهداشت جدول"
+msgstr "نگهداشت چندتایی جدول را غیر فعال کنید"
#: libraries/config/messages.inc.php:68
msgid "Edit SQL queries in popup window"
msgstr ""
#: libraries/config/messages.inc.php:69
-#, fuzzy
#| msgid "Edit next row"
msgid "Edit in window"
-msgstr "ویرایش کردن ردیف بعدی"
+msgstr "ویرایش کردن این پنجره"
#: libraries/config/messages.inc.php:70
-#, fuzzy
#| msgid "Display Features"
msgid "Display errors"
-msgstr "نمايش خصوصيات"
+msgstr "نمایش خطاها"
#: libraries/config/messages.inc.php:71
msgid "Gather errors"
@@ -4192,9 +4151,8 @@ msgid "Save as file"
msgstr "ذخيره به صورت پرونده"
#: libraries/config/messages.inc.php:75 libraries/config/messages.inc.php:247
-#, fuzzy
msgid "Character set of the file"
-msgstr "مجموعه كاراكترهاي پرونده:"
+msgstr "مجموعه كاراكترهاي پرونده"
#: libraries/config/messages.inc.php:76 libraries/config/messages.inc.php:92
#: tbl_gis_visualization.php:177 tbl_printview.php:352 tbl_structure.php:899
@@ -4217,7 +4175,6 @@ msgstr "فشردهسازي"
#: libraries/plugins/export/ExportOds.class.php:63
#: libraries/plugins/export/ExportOdt.class.php:119
#: libraries/plugins/export/ExportTexytext.class.php:79
-#, fuzzy
#| msgid "Put fields names in the first row"
msgid "Put columns names in the first row"
msgstr "قراردادن نام ستونها در اولين سطر"
@@ -4226,7 +4183,6 @@ msgstr "قراردادن نام ستونها در اولين سطر"
#: libraries/config/messages.inc.php:256
#: libraries/plugins/import/ImportCsv.class.php:188
#: libraries/plugins/import/ImportLdi.class.php:93
-#, fuzzy
#| msgid "Fields enclosed by"
msgid "Columns enclosed by"
msgstr "ستونهاي درميانگرفته با"
@@ -4235,7 +4191,6 @@ msgstr "ستونهاي درميانگرفته با"
#: libraries/config/messages.inc.php:257
#: libraries/plugins/import/ImportCsv.class.php:195
#: libraries/plugins/import/ImportLdi.class.php:100
-#, fuzzy
#| msgid "Fields escaped by"
msgid "Columns escaped by"
msgstr "ستونهاي جداشده با"
@@ -4257,10 +4212,9 @@ msgstr ""
#: libraries/config/messages.inc.php:261
#: libraries/plugins/import/ImportCsv.class.php:173
#: libraries/plugins/import/ImportLdi.class.php:86
-#, fuzzy
#| msgid "Lines terminated by"
msgid "Columns terminated by"
-msgstr "خطوط منتهي به"
+msgstr "ستون های از بین رفته به وسیله"
#: libraries/config/messages.inc.php:84 libraries/config/messages.inc.php:248
#: libraries/plugins/import/ImportCsv.class.php:202
@@ -4293,10 +4247,9 @@ msgstr ""
#: libraries/plugins/export/ExportOdt.class.php:61
#: libraries/plugins/export/ExportSql.class.php:252
#: libraries/plugins/export/ExportTexytext.class.php:50
-#, fuzzy
#| msgid "%s table(s)"
msgid "Dump table"
-msgstr "%s جدول(ها)"
+msgstr "بیرون کشیدن جدول"
#: libraries/config/messages.inc.php:96
#: libraries/plugins/export/ExportLatex.class.php:78
@@ -4328,15 +4281,13 @@ msgstr ""
#: libraries/config/messages.inc.php:104 libraries/config/messages.inc.php:116
#: libraries/config/messages.inc.php:140 tbl_relation.php:406
-#, fuzzy
msgid "Relations"
-msgstr "عمليات"
+msgstr "رابطه ها"
#: libraries/config/messages.inc.php:109
-#, fuzzy
#| msgid "Export"
msgid "Export method"
-msgstr "صدور"
+msgstr "روش صدور"
#: libraries/config/messages.inc.php:118 libraries/config/messages.inc.php:120
msgid "Save on server"
@@ -4352,10 +4303,9 @@ msgid "Remember file name template"
msgstr ""
#: libraries/config/messages.inc.php:124
-#, fuzzy
#| msgid "Enclose table and field names with backquotes"
msgid "Enclose table and column names with backquotes"
-msgstr "قراردادن نام جدولها و ستونها بين علامت نقلقول (\" ' \")"
+msgstr "قراردادن نام جدولها و ستونها بين علامت نقلقول"
#: libraries/config/messages.inc.php:125 libraries/config/messages.inc.php:268
#: libraries/display_export.lib.php:374
@@ -4372,9 +4322,8 @@ msgid "Creation/Update/Check dates"
msgstr ""
#: libraries/config/messages.inc.php:128
-#, fuzzy
msgid "Use delayed inserts"
-msgstr "وروديهاي تمديدشده"
+msgstr "از ورودی با تاخیر استفاده نمایید"
#: libraries/config/messages.inc.php:129
#: libraries/plugins/export/ExportSql.class.php:205
@@ -4386,10 +4335,9 @@ msgid "Use hexadecimal for BLOB"
msgstr ""
#: libraries/config/messages.inc.php:134
-#, fuzzy
#| msgid "Extended inserts"
msgid "Use ignore inserts"
-msgstr "وروديهاي تمديدشده"
+msgstr "از ورودی های درنظرگرفته نشده استفاده نمایید"
#: libraries/config/messages.inc.php:136
msgid "Syntax to use when inserting data"
@@ -4401,10 +4349,9 @@ msgid "Maximal length of created query"
msgstr ""
#: libraries/config/messages.inc.php:142
-#, fuzzy
#| msgid "Export"
msgid "Export type"
-msgstr "صدور"
+msgstr "نوع صدور"
#: libraries/config/messages.inc.php:143
#: libraries/plugins/export/ExportSql.class.php:193
@@ -4495,9 +4442,8 @@ msgid "Features"
msgstr ""
#: libraries/config/messages.inc.php:172
-#, fuzzy
msgid "General"
-msgstr "توليدشده توسط"
+msgstr "عمومی"
#: libraries/config/messages.inc.php:173
msgid "Set some commonly used options"
@@ -4525,9 +4471,8 @@ msgid "LaTeX"
msgstr ""
#: libraries/config/messages.inc.php:182
-#, fuzzy
msgid "Databases display options"
-msgstr "آمار پايگاههاي داده"
+msgstr "گزینه های نمایش پایگاه داده"
#: libraries/config/messages.inc.php:183 setup/frames/menu.inc.php:19
msgid "Navigation frame"
@@ -4539,7 +4484,6 @@ msgstr ""
#: libraries/config/messages.inc.php:185 libraries/select_server.lib.php:40
#: setup/frames/index.inc.php:117
-#, fuzzy
msgid "Servers"
msgstr "سرور"
@@ -4560,10 +4504,9 @@ msgid "Microsoft Office"
msgstr ""
#: libraries/config/messages.inc.php:192
-#, fuzzy
#| msgid "Documentation"
msgid "Open Document"
-msgstr "مستندات"
+msgstr "مستندات باز"
#: libraries/config/messages.inc.php:194
msgid "Other core settings"
@@ -4574,10 +4517,9 @@ msgid "Settings that didn't fit enywhere else"
msgstr ""
#: libraries/config/messages.inc.php:196
-#, fuzzy
#| msgid "Page number:"
msgid "Page titles"
-msgstr "شماره صفحه:"
+msgstr "عنوان صفحه"
#: libraries/config/messages.inc.php:197
msgid ""
@@ -4611,10 +4553,9 @@ msgid "Basic settings"
msgstr ""
#: libraries/config/messages.inc.php:203
-#, fuzzy
#| msgid "Documentation"
msgid "Authentication"
-msgstr "مستندات"
+msgstr "ورود"
#: libraries/config/messages.inc.php:204
msgid "Authentication settings"
@@ -4673,26 +4614,22 @@ msgstr ""
#: libraries/config/messages.inc.php:217 libraries/config/messages.inc.php:222
#: setup/frames/menu.inc.php:18
-#, fuzzy
msgid "SQL queries"
msgstr "پرس و جوي SQL"
#: libraries/config/messages.inc.php:219
-#, fuzzy
msgid "SQL Query box"
-msgstr "پرس و جوي SQL"
+msgstr "جعبه پرس و جوي SQL"
#: libraries/config/messages.inc.php:220
msgid "Customize links shown in SQL Query boxes"
msgstr ""
#: libraries/config/messages.inc.php:223
-#, fuzzy
msgid "SQL queries settings"
-msgstr "پرس و جوي SQL"
+msgstr "تنظیمات پرس و جوي SQL"
#: libraries/config/messages.inc.php:224
-#, fuzzy
msgid "SQL Validator"
msgstr "معتبرسازي SQL"
@@ -4733,7 +4670,6 @@ msgid "Settings for the table structure (list of columns)"
msgstr ""
#: libraries/config/messages.inc.php:232
-#, fuzzy
msgid "Tabs"
msgstr "جدول"
@@ -4916,7 +4852,7 @@ msgstr ""
#: libraries/config/messages.inc.php:285
msgid "Display databases in a tree"
-msgstr "پایگاه داده را در یک درخت نمایش بده."
+msgstr "پایگاه داده را در یک درخت نمایش بده"
#: libraries/config/messages.inc.php:286
msgid "Disable this if you want to see all databases at once"
@@ -4969,10 +4905,9 @@ msgid "Maximum number of recently used tables; set 0 to disable"
msgstr ""
#: libraries/config/messages.inc.php:298
-#, fuzzy
#| msgid "Analyze table"
msgid "Recently used tables"
-msgstr "تحليل جدول"
+msgstr "جدول های استفاده شده اخیر"
#: libraries/config/messages.inc.php:299
msgid ""
@@ -5105,10 +5040,9 @@ msgid "Use natural order for sorting table and database names"
msgstr ""
#: libraries/config/messages.inc.php:328
-#, fuzzy
#| msgid "Alter table order by"
msgid "Natural order"
-msgstr "تغيير جدول مرتب شده با"
+msgstr "نوبت خنثی"
#: libraries/config/messages.inc.php:329 libraries/config/messages.inc.php:339
msgid "Use only icons, only text or both"
@@ -5354,19 +5288,17 @@ msgid ""
msgstr ""
#: libraries/config/messages.inc.php:388
-#, fuzzy
#| msgid "Any host"
msgid "Control host"
-msgstr "همه ميزبانها"
+msgstr "کنترل هاست"
#: libraries/config/messages.inc.php:389
msgid "Count tables when showing database list"
msgstr ""
#: libraries/config/messages.inc.php:390
-#, fuzzy
msgid "Count tables"
-msgstr "No tables"
+msgstr "تعداد جداول"
#: libraries/config/messages.inc.php:391
msgid ""
@@ -5510,9 +5442,8 @@ msgid ""
msgstr ""
#: libraries/config/messages.inc.php:421
-#, fuzzy
msgid "Relation table"
-msgstr "مرمت جدول"
+msgstr "ارتباط جدول"
#: libraries/config/messages.inc.php:422
msgid "SQL command to fetch available databases"
@@ -5568,10 +5499,9 @@ msgid ""
msgstr ""
#: libraries/config/messages.inc.php:434
-#, fuzzy
#| msgid "Displaying Column Comments"
msgid "Display columns table"
-msgstr "نمايش توضيحات ستون"
+msgstr "نمایش جدول ستون ها"
#: libraries/config/messages.inc.php:435
msgid ""
@@ -5618,10 +5548,9 @@ msgid "Defines the list of statements the auto-creation uses for new versions."
msgstr ""
#: libraries/config/messages.inc.php:444
-#, fuzzy
#| msgid "Statements"
msgid "Statements to track"
-msgstr "شرج"
+msgstr "جملاتی که باید ردگیری شوند"
#: libraries/config/messages.inc.php:445
msgid ""
@@ -5640,9 +5569,8 @@ msgid ""
msgstr ""
#: libraries/config/messages.inc.php:448
-#, fuzzy
msgid "Automatically create versions"
-msgstr "نسخه سرور"
+msgstr "به صورت خودکار نسخه ایجاد شود"
#: libraries/config/messages.inc.php:449
msgid ""
@@ -5728,7 +5656,6 @@ msgid ""
msgstr ""
#: libraries/config/messages.inc.php:467
-#, fuzzy
msgid "Show display direction"
msgstr "آمار پايگاههاي داده"
@@ -5739,7 +5666,6 @@ msgid ""
msgstr ""
#: libraries/config/messages.inc.php:469
-#, fuzzy
msgid "Show field types"
msgstr "نمايش جدولها"
@@ -5756,7 +5682,6 @@ msgid "Whether to show hint or not"
msgstr ""
#: libraries/config/messages.inc.php:473
-#, fuzzy
#| msgid "Show grid"
msgid "Show hint"
msgstr "Show grid"
@@ -5789,7 +5714,6 @@ msgid ""
msgstr ""
#: libraries/config/messages.inc.php:480 libraries/sql_query_form.lib.php:377
-#, fuzzy
msgid "Retain query box"
msgstr "پرس و جوي SQL"
@@ -5798,7 +5722,6 @@ msgid "Allow to display database and table statistics (eg. space usage)"
msgstr ""
#: libraries/config/messages.inc.php:482
-#, fuzzy
msgid "Show statistics"
msgstr "آمار سطرها"
@@ -5869,9 +5792,8 @@ msgstr ""
#: libraries/config/messages.inc.php:500 tbl_tracking.php:526
#: tbl_tracking.php:585
-#, fuzzy
msgid "Username"
-msgstr "نام كاربر:"
+msgstr "نام كاربر"
#: libraries/config/messages.inc.php:501
msgid "A warning is displayed on the main page if Suhosin is detected"
@@ -5888,7 +5810,6 @@ msgid ""
msgstr ""
#: libraries/config/messages.inc.php:504
-#, fuzzy
#| msgid "Add/Delete Field Columns"
msgid "Textarea columns"
msgstr "اضافه يا حذف ستونها"
@@ -5912,7 +5833,6 @@ msgid "Title of browser window when nothing is selected"
msgstr ""
#: libraries/config/messages.inc.php:510
-#, fuzzy
#| msgid "Default"
msgid "Default title"
msgstr "پيشفرض"
@@ -6031,7 +5951,6 @@ msgstr ""
#: libraries/config/setup.forms.php:291
#: libraries/config/user_preferences.forms.php:192
-#, fuzzy
msgid "Database export options"
msgstr "آمار پايگاههاي داده"
@@ -6132,10 +6051,8 @@ msgstr "نتيجه ي جستجو \"%s \" %s:"
#, php-format
msgid "Total: %s match"
msgid_plural "Total: %s matches"
-msgstr[0] ""
-"مجموع: %s مطابقت"
-msgstr[1] ""
-"مجموع: %s مطابقتها"
+msgstr[0] "مجموع: %s مطابقت"
+msgstr[1] "مجموع: %s مطابقتها"
#: libraries/db_search.lib.php:211
#, php-format
@@ -6206,7 +6123,6 @@ msgstr ""
#: libraries/display_create_database.lib.php:21
#: libraries/display_create_database.lib.php:39
-#, fuzzy
#| msgid "Create new database"
msgid "Create database"
msgstr "ساخت پايگاه داده جديد"
@@ -6217,7 +6133,6 @@ msgstr "ساختن"
#: libraries/display_create_database.lib.php:43 server_privileges.php:185
#: server_privileges.php:1761 server_replication.php:36
-#, fuzzy
msgid "No Privileges"
msgstr "امتيازات"
@@ -6238,7 +6153,6 @@ msgid "Name"
msgstr "اسم"
#: libraries/display_create_table.lib.php:55
-#, fuzzy
#| msgid "Number of rows per page"
msgid "Number of columns"
msgstr "تعداد سطرها در هر صفحه"
@@ -6248,19 +6162,18 @@ msgid "Could not load export plugins, please check your installation!"
msgstr ""
#: libraries/display_export.lib.php:95
-#, fuzzy
#| msgid "Create table on database %s"
msgid "Exporting databases from the current server"
msgstr "ساخت جدول جديد در پايگاه داده %s"
#: libraries/display_export.lib.php:97
-#, fuzzy, php-format
+#, php-format
#| msgid "Create table on database %s"
msgid "Exporting tables from \"%s\" database"
msgstr "ساخت جدول جديد در پايگاه داده %s"
#: libraries/display_export.lib.php:99
-#, fuzzy, php-format
+#, php-format
#| msgid "Create table on database %s"
msgid "Exporting rows from \"%s\" table"
msgstr "ساخت جدول جديد در پايگاه داده %s"
@@ -6576,8 +6489,8 @@ msgid ""
"The size of the memory buffer InnoDB uses to cache data and indexes of its "
"tables."
msgstr ""
-"استفاده می کند به داده های ذخیره سازی و شاخص از جداول آن است InnoDB اندازه "
-"بافر حافظه از."
+"استفاده می کند به داده های ذخیره سازی و شاخص از جداول آن است InnoDB اندازه "
+" بافر حافظه از."
#: libraries/engines/innodb.lib.php:141
msgid "Buffer Pool"
@@ -8716,7 +8629,7 @@ msgstr ""
#: libraries/server_synchronize.lib.php:1555
msgid "Difference"
-msgstr ""
+msgstr "تفاوت"
#: libraries/server_synchronize.lib.php:1556 server_synchronize.php:1355
#, fuzzy
@@ -9615,7 +9528,7 @@ msgstr ""
#: server_privileges.php:109 server_privileges.php:347
#: server_privileges.php:759
msgid "Allows to set up events for the event scheduler"
-msgstr ""
+msgstr "دادن مجوز برای قرار دهی رویداد برای لیست رویدادهای زمانی"
#: server_privileges.php:110 server_privileges.php:381
#: server_privileges.php:747
@@ -9625,12 +9538,13 @@ msgstr ""
#: server_privileges.php:111 server_privileges.php:303
#: server_privileges.php:734
msgid "Allows importing data from and exporting data into files."
-msgstr ""
+msgstr "دادن اجازه برای وارد و خارج کردن اطلاعات از فایل ها."
#: server_privileges.php:112 server_privileges.php:765
msgid ""
"Allows adding users and privileges without reloading the privilege tables."
msgstr ""
+"دادن اجازه برای ایجاد کاربران و اعطای امتیازات بدون بارگذاری اطلاعات جداول."
#: server_privileges.php:113 server_privileges.php:311
#: server_privileges.php:741
@@ -13034,7 +12948,7 @@ msgid ""
"restarting after changing open_files_limit."
msgstr ""
"می توانید با افزایش {open_files_limit}، و چک کردن سابقه اجرایی در هنگام "
-"اجرای مجدد"
+"اجرای مجدد."
#: libraries/advisory_rules.txt:332
#, php-format
@@ -13399,9 +13313,8 @@ msgstr "مقدار concurrent_insert صفر میباشد"
#~ msgid "Dates only."
#~ msgstr "فقط دادهها"
-#, fuzzy
#~ msgid "Add a value"
-#~ msgstr "افزودن يك كاربر جديد"
+#~ msgstr "افزودن يك مقدار جديد"
#, fuzzy
#~ msgctxt "Correctly setup"
@@ -13493,12 +13406,12 @@ msgstr "مقدار concurrent_insert صفر میباشد"
#~ "a semicolon is missing somewhere. If you receive a blank page, "
#~ "everything is fine."
#~ msgstr ""
-#~ "phpMyAdmin قادر به خواندن پرونده تنظيمات نميباشد! اين ممكن است به "
-#~ "خاطر وجود يك مشكل دستوري و يا پيدانشدن پرونده توسط php باشد. لطفا "
-#~ "پرونده تنظميات را مستقيما توسط پيوند زير صدا زده و پيغام(هاي) خطاي php كه "
-#~ "دريافت ميكنيد را بخوانيد. در اكثر موارد يك علامت نقل قول (\" ' \") يا "
-#~ "ويرگولنقطه (\" ; \") در جايي وجود ندارد. اگر يك صفحه خالي دريافت "
-#~ "كرديد ، همه چيز درست است."
+#~ "phpMyAdmin قادر به خواندن پرونده تنظيمات نميباشد! اين ممكن است به خاطر "
+#~ "وجود يك مشكل دستوري و يا پيدانشدن پرونده توسط php باشد. لطفا پرونده "
+#~ "تنظميات را مستقيما توسط پيوند زير صدا زده و پيغام(هاي) خطاي php كه دريافت "
+#~ "ميكنيد را بخوانيد. در اكثر موارد يك علامت نقل قول (\" ' \") يا ويرگولنقطه (\" "
+#~ "; \") در جايي وجود ندارد. اگر يك صفحه خالي دريافت كرديد ، همه چيز درست "
+#~ "است."
#~ msgid "seconds"
#~ msgstr "ثانیه"
@@ -13536,8 +13449,8 @@ msgstr "مقدار concurrent_insert صفر میباشد"
#~ "The additional features for working with linked tables have been "
#~ "deactivated. To find out why click %shere%s."
#~ msgstr ""
-#~ "امكانات اضافي براي كاركردن با جدولهاي پيوندي غيرفعال شدهاست . براي "
-#~ "پيداكردن دليل آن %sاينجا%s را بزنيد ."
+#~ "امكانات اضافي براي كاركردن با جدولهاي پيوندي غيرفعال شدهاست . براي پيداكردن "
+#~ "دليل آن %sاينجا%s را بزنيد ."
#~ msgid "No tables"
#~ msgstr "No tables"
@@ -13551,22 +13464,20 @@ msgstr "مقدار concurrent_insert صفر میباشد"
#~ "those values, precede it with a backslash (for example '\\\\xyz' or 'a"
#~ "\\'b')."
#~ msgstr ""
-#~ "اگر نوع ستون \"enum\" يا \"set\" ميباشد ، لطفا براي ورود مقادير از اين "
-#~ "قالب استفاده نماييد : 'a','b','c'... اگر احتياج داشتيد كه از علامت "
-#~ "مميز برعكس(بكاسلش) (\" \\ \") يا نقلقول تكي (\" ' \") در آن مقادير "
-#~ "استفاده نماييد ، قبل از آنها علامت (\" \\ \") را بگذاريد (براي "
-#~ "مثال'\\\\xyz' يا 'a\\'b')"
+#~ "اگر نوع ستون \"enum\" يا \"set\" ميباشد ، لطفا براي ورود مقادير از اين قالب "
+#~ "استفاده نماييد : 'a','b','c'... اگر احتياج داشتيد كه از علامت مميز "
+#~ "برعكس(بكاسلش) (\" \\ \") يا نقلقول تكي (\" ' \") در آن مقادير استفاده نماييد ، "
+#~ "قبل از آنها علامت (\" \\ \") را بگذاريد (براي مثال'\\\\xyz' يا 'a\\'b')"
#~ msgid ""
#~ "Enter each value in a separate field. If you ever need to put a backslash "
#~ "(\"\\\") or a single quote (\"'\") amongst those values, precede it with "
#~ "a backslash (for example '\\\\xyz' or 'a\\'b')."
#~ msgstr ""
-#~ "اگر نوع ستون \"enum\" يا \"set\" ميباشد ، لطفا براي ورود مقادير از اين "
-#~ "قالب استفاده نماييد : 'a','b','c'... اگر احتياج داشتيد كه از علامت "
-#~ "مميز برعكس(بكاسلش) (\" \\ \") يا نقلقول تكي (\" ' \") در آن مقادير "
-#~ "استفاده نماييد ، قبل از آنها علامت (\" \\ \") را بگذاريد (براي "
-#~ "مثال'\\\\xyz' يا 'a\\'b')"
+#~ "اگر نوع ستون \"enum\" يا \"set\" ميباشد ، لطفا براي ورود مقادير از اين قالب "
+#~ "استفاده نماييد : 'a','b','c'... اگر احتياج داشتيد كه از علامت مميز "
+#~ "برعكس(بكاسلش) (\" \\ \") يا نقلقول تكي (\" ' \") در آن مقادير استفاده نماييد ، "
+#~ "قبل از آنها علامت (\" \\ \") را بگذاريد (براي مثال'\\\\xyz' يا 'a\\'b')"
#~ msgid "New table"
#~ msgstr "No tables"
@@ -13609,10 +13520,9 @@ msgstr "مقدار concurrent_insert صفر میباشد"
#~ "conversion. Either configure PHP to enable these extensions or disable "
#~ "charset conversion in phpMyAdmin."
#~ msgstr ""
-#~ "بارگذاري iconv يا recode extension كه براي تبديل مجموعه كاراكترها لازم "
-#~ "است ، مقدور نميباشد، php را براي اجازه استفاده از آنها تنظيم كرده و يا "
-#~ "تبديل مجموعه كاراكترها (charset conversion) را در phpMyAdmin غيرفعال "
-#~ "نماييد."
+#~ "بارگذاري iconv يا recode extension كه براي تبديل مجموعه كاراكترها لازم است "
+#~ "، مقدور نميباشد، php را براي اجازه استفاده از آنها تنظيم كرده و يا تبديل "
+#~ "مجموعه كاراكترها (charset conversion) را در phpMyAdmin غيرفعال نماييد."
#~ msgid "Field"
#~ msgstr "ستون"
diff --git a/po/nb.po b/po/nb.po
index 3672ea8f74..a36a92dfca 100644
--- a/po/nb.po
+++ b/po/nb.po
@@ -4,15 +4,15 @@ msgstr ""
"Project-Id-Version: phpMyAdmin 4.0.0-dev\n"
"Report-Msgid-Bugs-To: phpmyadmin-devel@lists.sourceforge.net\n"
"POT-Creation-Date: 2012-07-03 09:19+0200\n"
-"PO-Revision-Date: 2012-05-17 15:22+0200\n"
-"Last-Translator: Michal Čihař \n"
+"PO-Revision-Date: 2012-07-04 16:03+0200\n"
+"Last-Translator: Nicholas Arnesen \n"
"Language-Team: norwegian \n"
"Language: nb\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
"Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Weblate 1.0\n"
+"X-Generator: Weblate 1.1\n"
#: browse_foreigners.php:36 browse_foreigners.php:60 js/messages.php:354
#: libraries/DisplayResults.class.php:609 server_privileges.php:1851
@@ -301,7 +301,7 @@ msgstr "Fjern database"
#: db_operations.php:505
#, php-format
msgid "Database %s has been dropped."
-msgstr "Databasen %s har blitt slettet"
+msgstr "Databasen %s har blitt slettet."
#: db_operations.php:510
msgid "Drop the database (DROP)"
@@ -823,7 +823,7 @@ msgstr "Geometri"
#: gis_data_editor.php:161 js/messages.php:322
msgid "Point"
-msgstr ""
+msgstr "Punkt"
#: gis_data_editor.php:162 gis_data_editor.php:186 gis_data_editor.php:234
#: gis_data_editor.php:286 js/messages.php:320
@@ -839,12 +839,12 @@ msgstr "Y"
#: js/messages.php:323
#, php-format
msgid "Point %d"
-msgstr ""
+msgstr "Peker %d"
#: gis_data_editor.php:193 gis_data_editor.php:239 gis_data_editor.php:291
#: js/messages.php:329
msgid "Add a point"
-msgstr ""
+msgstr "Legg til peker"
#: gis_data_editor.php:209 js/messages.php:324
msgid "Linestring"
@@ -929,8 +929,9 @@ msgid ""
"[a@./Documentation.html#faq1_16@Documentation]FAQ 1.16[/a]."
msgstr ""
"Ingen data ble mottatt for importering. Enten ble ingen filnavn gitt, eller "
-"filstørrelsen oversteg maksimum størrelse tillatt i din PHP konfigurasjon. "
-"Se FAQ 1.16"
+"så var filstørrelsen over maksimum størrelse tillatt i din PHP "
+"konfigurasjon. Se [a@./Documentation.html#faq1_16@Documentation]FAQ "
+"1.16[/a]."
#: import.php:412
msgid ""
@@ -1202,7 +1203,7 @@ msgstr "System minne"
#: js/messages.php:99
msgid "System swap"
-msgstr "System swap"
+msgstr "Systembytte"
#. l10n: shortcuts for Megabyte
#: js/messages.php:100 js/messages.php:123
@@ -1341,8 +1342,9 @@ msgid "Resume monitor"
msgstr "Gjenoppta monitor"
#: js/messages.php:141
+#, fuzzy
msgid "Pause monitor"
-msgstr "Pause monitor"
+msgstr "Pause skjerm"
#: js/messages.php:143
msgid "general_log and slow_query_log are enabled."
@@ -1583,7 +1585,7 @@ msgstr "Tabellvisningsinnstillinger"
#. l10n: Filter as in "Start Filtering"
#: js/messages.php:197
msgid "Filter"
-msgstr "Filter"
+msgstr "Filtrer"
#: js/messages.php:198
msgid "Filter queries by word/regexp:"
@@ -2446,19 +2448,19 @@ msgstr "Dokumentasjon"
#: libraries/CommonFunctions.class.php:534
msgctxt "MySQL 5.5 documentation language"
msgid "en"
-msgstr "en"
+msgstr "no"
#. l10n: Please check that translation actually exists.
#: libraries/CommonFunctions.class.php:538
msgctxt "MySQL 5.1 documentation language"
msgid "en"
-msgstr "en"
+msgstr "no"
#. l10n: Please check that translation actually exists.
#: libraries/CommonFunctions.class.php:542
msgctxt "MySQL 5.0 documentation language"
msgid "en"
-msgstr "en"
+msgstr "no"
#: libraries/CommonFunctions.class.php:670 libraries/Message.class.php:199
#: libraries/core.lib.php:217 libraries/import.lib.php:154
@@ -2528,9 +2530,10 @@ msgid "Inline edit of this query"
msgstr "Inline redigering av denne spørringa"
#: libraries/CommonFunctions.class.php:1405
+#, fuzzy
msgctxt "Inline edit query"
msgid "Inline"
-msgstr "Inline"
+msgstr "Innebygd"
#: libraries/CommonFunctions.class.php:1476 sql.php:1036
msgid "Profiling"
@@ -3245,7 +3248,7 @@ msgstr "Funksjon"
#: pmd_general.php:658 pmd_general.php:671 pmd_general.php:734
#: pmd_general.php:788
msgid "Operator"
-msgstr "Operator"
+msgstr "Operatør"
#: libraries/TableSearch.class.php:219 libraries/TableSearch.class.php:1238
#: libraries/insert_edit.lib.php:1600 libraries/replication_gui.lib.php:119
@@ -3971,9 +3974,9 @@ msgid ""
"inside a frame, and is a potential [strong]security hole[/strong] allowing "
"cross-frame scripting attacks"
msgstr ""
-"Å tillate dette gir sider på andre domener muligheten til å innlemme "
+"Å tillate dette gir sider på andre domener muligheten til å legge inn "
"phpMyAdmin i en ramme, og er et potensielt [strong]sikkerhetshull[/strong] "
-"og muligjør cross-site scripting."
+"og muligjør cross-frame skripting"
#: libraries/config/messages.inc.php:22
msgid "Allow third party framing"
@@ -3992,8 +3995,9 @@ msgstr ""
"autentisering"
#: libraries/config/messages.inc.php:25
+#, fuzzy
msgid "Blowfish secret"
-msgstr "Blowfish secret"
+msgstr "Blowfish hemmelighet"
#: libraries/config/messages.inc.php:26
msgid "Highlight selected rows"
@@ -4122,7 +4126,7 @@ msgstr "Bekreft DROP spørringer"
#: libraries/config/messages.inc.php:50
msgid "Debug SQL"
-msgstr "Debug SQL"
+msgstr "Feilsøk SQL"
#: libraries/config/messages.inc.php:51
msgid "Default display direction"
@@ -5639,7 +5643,7 @@ msgstr "Signon sesjonsnavn"
#: libraries/config/messages.inc.php:426
msgid "Signon URL"
-msgstr "Signon URL"
+msgstr "Innloggingslink"
#: libraries/config/messages.inc.php:427
msgid "Socket on which MySQL server is listening, leave empty for default"
@@ -6241,7 +6245,7 @@ msgstr "Ugyldig IP addresse: %s"
#: libraries/core.lib.php:255
msgctxt "PHP documentation language"
msgid "en"
-msgstr "en"
+msgstr "no"
#: libraries/core.lib.php:276
#, php-format
@@ -6410,7 +6414,7 @@ msgstr "Eksporter rader fra %s tabell"
#: libraries/display_export.lib.php:105
msgid "Export Method:"
-msgstr "Eksportmetode"
+msgstr "Eksportmetode:"
#: libraries/display_export.lib.php:121
msgid "Quick - display only the minimal options"
@@ -7492,7 +7496,7 @@ msgstr "Du kan skrive vertsnavn/IP adresse og port separert med mellomrom."
#: libraries/plugins/auth/AuthenticationCookie.class.php:181
msgid "Server:"
-msgstr "Tjener"
+msgstr "Tjener:"
#: libraries/plugins/auth/AuthenticationCookie.class.php:193
msgid "Username:"
@@ -8154,8 +8158,8 @@ msgid ""
"Displays a clickable thumbnail. The options are the maximum width and height "
"in pixels. The original aspect ratio is preserved."
msgstr ""
-"Viser et klikkbart tommelfingerbilde; valg: bredde, høyde i piksler (bevarer "
-"originale forhold)"
+"Viser et klikkbart ministyrbilde. Valgene er satt til maksimum lengde og "
+"høyde i piksler. Det opprinnelige størrelsesforholdet blir bevart."
#: libraries/plugins/transformations/abstract/LongToIPv4TransformationsPlugin.class.php:31
msgid ""
@@ -8984,7 +8988,7 @@ msgstr "Vis tabelldimensjoner"
#: libraries/schema/User_Schema.class.php:455
msgid "Display all tables with the same width"
-msgstr "vis alle tabeller med samme bredde?"
+msgstr "Vis alle tabeller med samme lengde"
#: libraries/schema/User_Schema.class.php:460
msgid "Only show keys"
@@ -9115,8 +9119,8 @@ msgid ""
"below, if there is any, may also help you in diagnosing the problem"
msgstr ""
"Det ser ut til å være en feil i din SQL-spørring. En eventuell feilmelding "
-"fra MySQL-tjeneren er skrevet ut nedenfor, kan kanskje hjelpe deg med å "
-"finne feilen."
+"fra MySQL-tjeneren er skrevet ut nedenfor, og kan kanskje hjelpe deg med å "
+"finne feilen"
#: libraries/sqlparser.lib.php:171
msgid ""
@@ -10602,8 +10606,9 @@ msgstr ""
"phpMyAdmin kunne ikke avslutte tråd %s. Den er sansynligvis alt avsluttet."
#: server_status.php:616
+#, fuzzy
msgid "Handler"
-msgstr "Handler"
+msgstr "Behandler"
#: server_status.php:617
msgid "Query cache"
@@ -10639,7 +10644,7 @@ msgstr "Transaksjonskoordinator"
#: server_status.php:639
msgid "Flush (close) all tables"
-msgstr "Flush (close) all tables"
+msgstr "Flush (lukk) alle tabeller"
#: server_status.php:641
msgid "Show open tables"
@@ -10655,7 +10660,7 @@ msgstr "Vis slavestatus"
#: server_status.php:657
msgid "Flush query cache"
-msgstr "Flush query cache"
+msgstr "Flush spørringsbufferen"
#: server_status.php:797
msgid "Runtime Information"
@@ -12676,14 +12681,13 @@ msgid "Distinct values"
msgstr "Se gjennom distinkte verdier"
#: tbl_structure.php:166 tbl_structure.php:167
-#, fuzzy
#| msgid "Adding Primary Key"
msgid "Add primary key"
-msgstr "Legger til primærnøkkel"
+msgstr "Legg til primærnøkkel"
#: tbl_structure.php:170 tbl_structure.php:171
msgid "Add unique index"
-msgstr ""
+msgstr "Legg til unik indeks"
#: tbl_structure.php:172 tbl_structure.php:173
#, fuzzy
diff --git a/po/pt_BR.po b/po/pt_BR.po
index c973384433..06e7963bfe 100644
--- a/po/pt_BR.po
+++ b/po/pt_BR.po
@@ -4,8 +4,8 @@ msgstr ""
"Project-Id-Version: phpMyAdmin 4.0.0-dev\n"
"Report-Msgid-Bugs-To: phpmyadmin-devel@lists.sourceforge.net\n"
"POT-Creation-Date: 2012-07-03 09:19+0200\n"
-"PO-Revision-Date: 2012-06-28 16:25+0200\n"
-"Last-Translator: Alexsandro Preis Dubinski \n"
+"PO-Revision-Date: 2012-07-04 15:59+0200\n"
+"Last-Translator: Marcelo Altmann \n"
"Language-Team: brazilian_portuguese \n"
"Language: pt_BR\n"
"MIME-Version: 1.0\n"
@@ -1881,10 +1881,9 @@ msgid "To zoom in, select a section of the plot with the mouse."
msgstr "Para ampliar, selecione um trecho do gráfico com o mouse."
#: js/messages.php:306
-#, fuzzy
#| msgid "Click reset zoom link to come back to original state."
msgid "Click reset zoom button to come back to original state."
-msgstr "Clique no link resetar zoom para voltar ao estado original"
+msgstr "Clique no botão resetar zoom para voltar ao estado original"
#: js/messages.php:308
msgid "Click a data point to view and possibly edit the data row."
@@ -2013,6 +2012,8 @@ msgstr "Copiar nome coluna"
#: js/messages.php:359
msgid "Right-click the column name to copy it to your clipboard."
msgstr ""
+"Clique com o botão direito do mouse para copiar\n"
+"Right-click the column name to copy it to your clipboard."
#: js/messages.php:360
msgid "Show data row(s)"
@@ -6893,7 +6894,7 @@ msgstr ""
#: libraries/engines/pbxt.lib.php:135
msgid "Related Links"
-msgstr "Links relatados"
+msgstr "Links relacionados"
#: libraries/engines/pbxt.lib.php:137
msgid "The PrimeBase XT Blog by Paul McCullagh"
diff --git a/libraries/db_search.lib.php b/libraries/db_search.lib.php
index 14032db9dd..5720246dc1 100644
--- a/libraries/db_search.lib.php
+++ b/libraries/db_search.lib.php
@@ -14,7 +14,7 @@ if (! defined('PHPMYADMIN')) {
*
* @param string $table The table name
* @param string $criteriaColumnName Restrict the search to this column
- * @param string $criteriaSearchString The string to search
+ * @param string $criteriaSearchString The search word/phrase/regexp to be searched
* @param integer $criteriaSearchType Type of search
* (1 -> 1 word at least, 2 -> all words,
* 3 -> exact string, 4 -> regexp)
@@ -33,24 +33,18 @@ if (! defined('PHPMYADMIN')) {
function PMA_getSearchSqls($table, $criteriaColumnName, $criteriaSearchString,
$criteriaSearchType
) {
+ $common_functions = PMA_CommonFunctions::getInstance();
// Statement types
$sqlstr_select = 'SELECT';
$sqlstr_delete = 'DELETE';
// Table to use
$sqlstr_from = ' FROM '
- . PMA_backquote($GLOBALS['db']) . '.' . PMA_backquote($table);
- // Search words or pattern
- $search_words = (($criteriaSearchType > 2)
- ? array($criteriaSearchString) : explode(' ', $criteriaSearchString));
-
- $like_or_regex = (($criteriaSearchType == 4) ? 'REGEXP' : 'LIKE');
- $automatic_wildcard = (($criteriaSearchType < 3) ? '%' : '');
-
+ . $common_functions->backquote($GLOBALS['db']) . '.'
+ . $common_functions->backquote($table);
+ // Gets where clause for the query
$where_clause = PMA_dbSearchGetWhereClause(
- $table, $search_words, $criteriaSearchType, $criteriaColumnName,
- $like_or_regex, $automatic_wildcard
+ $table, $criteriaSearchString, $criteriaSearchType, $criteriaColumnName
);
-
// Builds complete queries
$sql['select_columns'] = $sqlstr_select . ' * ' . $sqlstr_from . $where_clause;
// here, I think we need to still use the COUNT clause, even for
@@ -65,24 +59,35 @@ function PMA_getSearchSqls($table, $criteriaColumnName, $criteriaSearchString,
/**
* Provides where clause for bulding SQL query
*
- * @param string $table the table name
- * @param integer $search_words Search words or pattern
- * @param integer $criteriaSearchType Type of search
- * (1 -> 1 word at least, 2 -> all words,
- * 3 -> exact string, 4 -> regexp)
- * @param string $criteriaColumnName Restrict the search to this column
- * @param string $like_or_regex Whether to use 'LIKE' or 'REGEXP'
- * @param string $automatic_wildcard Use automatic wildcard
+ * @param string $table The table name
+ * @param integer $criteriaSearchString The search word/phrase/regexp to be searched
+ * @param integer $criteriaSearchType Type of search
+ * (1 -> 1 word at least, 2 -> all words,
+ * 3 -> exact string, 4 -> regexp)
+ * @param string $criteriaColumnName Restrict the search to this column
*
* @return string The generated where clause
*/
-function PMA_dbSearchGetWhereClause($table, $search_words, $criteriaSearchType,
- $criteriaColumnName, $like_or_regex, $automatic_wildcard
+function PMA_dbSearchGetWhereClause($table, $criteriaSearchString,
+ $criteriaSearchType, $criteriaColumnName
) {
+ $common_functions = PMA_CommonFunctions::getInstance();
$where_clause = '';
// Columns to select
$allColumns = PMA_DBI_get_columns($GLOBALS['db'], $table);
$likeClauses = array();
+ // Based on search type, decide like/regex & '%'/''
+ $like_or_regex = (($criteriaSearchType == 4) ? 'REGEXP' : 'LIKE');
+ $automatic_wildcard = (($criteriaSearchType < 3) ? '%' : '');
+ // For "as regular expression" (search option 4), LIKE won't be used
+ // Usage example: If user is seaching for a literal $ in a regexp search,
+ // he should enter \$ as the value.
+ $criteriaSearchString = $common_functions->sqlAddSlashes(
+ $criteriaSearchString, ($criteriaSearchType == 4 ? false : true)
+ );
+ // Extract search words or pattern
+ $search_words = (($criteriaSearchType > 2)
+ ? array($criteriaSearchString) : explode(' ', $criteriaSearchString));
foreach ($search_words as $search_word) {
// Eliminates empty values
@@ -98,8 +103,9 @@ function PMA_dbSearchGetWhereClause($table, $search_words, $criteriaSearchType,
) {
// Drizzle has no CONVERT and all text columns are UTF-8
$column = ((PMA_DRIZZLE)
- ? PMA_backquote($column['Field'])
- : 'CONVERT(' . PMA_backquote($column['Field']) . ' USING utf8)');
+ ? $common_functions->backquote($column['Field'])
+ : 'CONVERT(' . $common_functions->backquote($column['Field'])
+ . ' USING utf8)');
$likeClausesPerColumn[] = $column . ' ' . $like_or_regex . ' '
. "'"
. $automatic_wildcard . $search_word . $automatic_wildcard
@@ -110,14 +116,16 @@ function PMA_dbSearchGetWhereClause($table, $search_words, $criteriaSearchType,
$likeClauses[] = implode(' OR ', $likeClausesPerColumn);
}
} // end for
-
+ // Use 'OR' if 'at least one word' is to be searched, else use 'AND'
$implode_str = ($criteriaSearchType == 1 ? ' OR ' : ' AND ');
if ( empty($likeClauses)) {
// this could happen when the "inside column" does not exist
// in any selected tables
$where_clause = ' WHERE FALSE';
} else {
- $where_clause = ' WHERE (' . implode(') ' . $implode_str . ' (', $likeClauses) . ')';
+ $where_clause = ' WHERE ('
+ . implode(') ' . $implode_str . ' (', $likeClauses)
+ . ')';
}
return $where_clause;
}
@@ -125,18 +133,17 @@ function PMA_dbSearchGetWhereClause($table, $search_words, $criteriaSearchType,
/**
* Displays database search results
*
* @param array $criteriaTables Tables on which search is to be performed
* @param string $searched The search word/phrase/regexp
* @param string $option_str Type of search
* @param string $criteriaSearchString The string to search
* @param integer $criteriaSearchType Type of search
* (1 -> 1 word at least, 2 -> all words,
* 3 -> exact string, 4 -> regexp)
* @param string $criteriaColumnName Restrict the search to this column
*
* @return string HTML for search results
*/
-function PMA_dbSearchGetSearchResults($criteriaTables, $searched, $option_str,
+function PMA_dbSearchGetSearchResults($criteriaTables, $searchTypeDescription,
$criteriaSearchString, $criteriaSearchType, $criteriaColumnName = null
) {
$html_output = '';
@@ -146,7 +153,7 @@ function PMA_dbSearchGetSearchResults($criteriaTables, $searched, $option_str,
. '
';
@@ -162,13 +169,14 @@ function PMA_dbSearchGetSearchResults($criteriaTables, $searched, $option_str,
// Executes the "COUNT" statement
$res_cnt = PMA_DBI_fetch_value($newsearchsqls['select_count']);
$num_search_result_total += $res_cnt;
+ // Gets the result row's HTML for a table
$html_output .= PMA_dbSearchGetResultsRow(
$each_table, $newsearchsqls, $odd_row
);
$odd_row = ! $odd_row;
} // end for
$html_output .= '';
-
+ // Displays total number of matches
if (count($criteriaTables) > 1) {
$html_output .= '';
$html_output .= sprintf(
@@ -205,6 +213,7 @@ function PMA_dbSearchGetResultsRow($each_table, $newsearchsqls, $odd_row)
$res_cnt = PMA_DBI_fetch_value($newsearchsqls['select_count']);
// Start forming search results row
$html_output = '
';
+ // Displays results count for a table
$html_output .= '';
$html_output .= sprintf(
_ngettext(
@@ -214,7 +223,7 @@ function PMA_dbSearchGetResultsRow($each_table, $newsearchsqls, $odd_row)
$res_cnt, htmlspecialchars($each_table)
);
$html_output .= ' ';
-
+ // Displays browse/delete link if result count > 0
if ($res_cnt > 0) {
$this_url_params['sql_query'] = $newsearchsqls['select_columns'];
$browse_result_path = 'sql.php' . PMA_generate_common_url($this_url_params);
@@ -246,18 +255,19 @@ function PMA_dbSearchGetResultsRow($each_table, $newsearchsqls, $odd_row)
/**
* Provides the main search form's html
*
- * @param string $searched Keyword/Regular expression to be searched
- * @param integer $criteriaSearchType Type of search (one word, phrase etc.)
- * @param array $tables_names_only Names of all tables
- * @param array $criteriaTables Tables on which search is to be performed
- * @param array $url_params URL parameters
- * @param string $criteriaColumnName Restrict the search to this column
+ * @param string $criteriaSearchString Keyword/Regular expression earlier entered
+ * @param integer $criteriaSearchType Type of search (one word, phrase etc.)
+ * @param array $tables_names_only Names of all tables
+ * @param array $criteriaTables Tables on which search is to be performed
+ * @param array $url_params URL parameters
+ * @param string $criteriaColumnName Restrict the search to this column
*
* @return string HTML for selection form
*/
-function PMA_dbSearchGetSelectionForm($searched, $criteriaSearchType,
+function PMA_dbSearchGetSelectionForm($criteriaSearchString, $criteriaSearchType,
$tables_names_only, $criteriaTables, $url_params, $criteriaColumnName = null
) {
+ $common_functions = PMA_CommonFunctions::getInstance();
$html_output = ' ';
$html_output .= ' ';
// choices for types of search
$html_output .= '';
$html_output .= '' . __('Find:') . ' ';
$html_output .= '';
$choices = array(
- '1' => __('at least one of the words') . PMA_showHint(__('Words are separated by a space character (" ").')),
- '2' => __('all words') . PMA_showHint(__('Words are separated by a space character (" ").')),
+ '1' => __('at least one of the words')
+ . $common_functions->showHint(
+ __('Words are separated by a space character (" ").')
+ ),
+ '2' => __('all words')
+ . $common_functions->showHint(
+ __('Words are separated by a space character (" ").')
+ ),
'3' => __('the exact phrase'),
- '4' => __('as regular expression') . ' ' . PMA_showMySQLDocu('Regexp', 'Regexp')
+ '4' => __('as regular expression')
+ . ' ' . $common_functions->showMySQLDocu('Regexp', 'Regexp')
);
// 4th parameter set to true to add line breaks
// 5th parameter set to false to avoid htmlspecialchars() escaping in the label
// since we have some HTML in some labels
- $html_output .= PMA_getRadioFields(
+ $html_output .= $common_functions->getRadioFields(
'criteriaSearchType', $choices, $criteriaSearchType, true, false
);
$html_output .= ' ';
@@ -308,18 +325,27 @@ function PMA_dbSearchGetSelectionForm($searched, $criteriaSearchType,
. '';
} // end for
$html_output .= '';
- $alter_select
- = '' . __('Select All') . ' '
- . ' / '
- . '' . __('Unselect All') . ' ';
$html_output .= '';
+ // Displays 'select all' and 'unselect all' links
+ $alter_select = ''
+ . __('Select All') . ' / ';
+ $alter_select .= ''
+ . __('Unselect All') . ' ';
$html_output .= '' . $alter_select . ' ';
+ // Inputbox for column name entry
$html_output .= '';
$html_output .= '' . __('Inside column:') . ' ';
$html_output .= ' ';
$html_output .= ' ';
$html_output .= '';
@@ -348,8 +374,8 @@ function getResultDivs()
$html_output .= '';
// div for browsing results
$html_output .= '';
- $html_output .= '';
+ $html_output .= '';
$html_output .= '
';
$html_output .= ' ';
@@ -125,18 +133,17 @@ function PMA_dbSearchGetWhereClause($table, $search_words, $criteriaSearchType,
* Displays database search results
*
- * @param array $criteriaTables Tables on which search is to be performed
- * @param string $searched The search word/phrase/regexp
- * @param string $option_str Type of search
- * @param string $criteriaSearchString The string to search
- * @param integer $criteriaSearchType Type of search
- * (1 -> 1 word at least, 2 -> all words,
- * 3 -> exact string, 4 -> regexp)
- * @param string $criteriaColumnName Restrict the search to this column
+ * @param array $criteriaTables Tables on which search is to be performed
+ * @param string $searchTypeDescription Description for search type
+ * @param string $criteriaSearchString The search word/phrase/regexp to be searched
+ * @param integer $criteriaSearchType Type of search
+ * (1 -> 1 word at least, 2 -> all words,
+ * 3 -> exact string, 4 -> regexp)
+ * @param string $criteriaColumnName Restrict the search to this column
*
* @return string HTML for search results
$html_output .= '';